include <../libs/rounded_shapes.scad>

make_base = false;
make_bridge = false;

// For songle SRD-24VDC-SL-C rleay
relay_width = 38/64.0 * 25.4;
relay_depth = 47.05/64.0 * 25.4;
relay_height = 15.1; // approximate

base_thickness = 1.12;

base_dim = 56.7;
base_rounding_radius = 3;

socket_lip = 1.0;
socket_margin = 0.11;
socket_height = 2.5;

socket_width = socket_margin + socket_lip*2 + relay_width;
socket_depth = socket_margin + socket_lip*2 + relay_depth;

bnc_hole_diameter = 24/64 * 25.4;
bnc_mounting_hole_radius = (bnc_hole_diameter + 0.1)/2;

bnc_mount_thickness = 2.1;
bnc_margin = 0.66;
bnc_mount_dim = 1/2 * 25.4 + bnc_margin;
bnc_mount_z_dim = relay_height + bnc_mounting_hole_radius + 2;

mounting_hole_dia = 25.4 * 9/64.0;
mounting_hole_offset = base_thickness + 3.22;

$fn = 33;

bridge_thickness = mounting_hole_dia + 2; 


bridge_width = bnc_mount_dim + 2;
bridge_height = bnc_mount_z_dim + base_thickness + bridge_thickness + 3; // Adding 3 here so the BNC connector isnt so low
bridge_top_thickness = 2;

bridge_cut_coeff = 0.36;

module relay_socket(){    
    translate([socket_width * -0.5, socket_depth * -0.5, 0]){
        color("red") difference(){
            cube([socket_width, socket_depth, socket_height]);
            translate([socket_lip,socket_lip,-1]){
                cube([relay_width + socket_margin, relay_depth + socket_margin, socket_height + 2]);
            }
        }
    }
}

module relay_socket_and_bnc(){
    union(){
        relay_socket();
        translate([(relay_width/2 +bnc_mount_dim/2 + bnc_mount_thickness + socket_margin) * -1,0,0]){
            rotate([-0,0,-0]){
                bnc_mount();
            }
        }
    }
}

module bnc_mount(){
    translate([bnc_mount_dim*-0.5,bnc_mount_dim * -0.71,0]){
    union(){
    difference(){
        cube([bnc_mount_dim, bnc_mount_thickness, bnc_mount_z_dim]);                
        translate([bnc_mount_dim/2,2,bnc_mount_z_dim - bnc_mounting_hole_radius - (bnc_margin*2.88)]){
            rotate([-90,0,0]){
                cylinder( h = bnc_mount_thickness * 3, r = bnc_mounting_hole_radius, center = true);
            }
        }
    }
    
    translate([bnc_mount_dim,0,0]){
        difference(){
        cube([bnc_mount_thickness, bnc_mount_dim, bnc_mount_z_dim]);
        translate([1,bnc_mount_dim ,bnc_mount_z_dim ]){
            rotate([0,90,0]){
                scale([1.95,0.92,1]){
                    cylinder(h = bnc_mount_thickness * 2, r = bnc_mount_z_dim /2, center = true);
                }
            }
        }
    }
    }
    
    translate([- 1 * bnc_mount_thickness,0,0]){
        difference(){
        cube([bnc_mount_thickness, bnc_mount_dim, bnc_mount_z_dim]);
        union(){
            translate([1,bnc_mount_dim  ,bnc_mount_z_dim  ]){
                rotate([0,90,0]){
                    scale([1.95,0.92,1]){
                        cylinder(h = bnc_mount_thickness * 2, r = bnc_mount_z_dim/2, center = true);
                    }
                }
            }
            translate([bnc_mount_thickness/2,bnc_mount_dim,0]){
                cylinder( h = bnc_mount_z_dim, r = mounting_hole_dia, center = true);
            }
        }
    }
    }
    
    
    }
}
}

if (make_base) {
union(){
    difference(){
        rounded_rectangle(base_dim, base_dim, base_thickness, base_rounding_radius);
        union(){
            translate([mounting_hole_offset,base_dim/2 - socket_width/2 - mounting_hole_dia,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([base_dim/2 + socket_width/2 + mounting_hole_dia,mounting_hole_offset,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([base_dim/2 - socket_width/2 - mounting_hole_dia,base_dim - mounting_hole_offset,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([base_dim - mounting_hole_offset,base_dim/2 + socket_width/2 + mounting_hole_dia,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
            
            translate([base_dim/2,base_dim/2,base_thickness -1]){
                cylinder(h = base_thickness * 2, r = mounting_hole_dia/2, center = true, $fn =28);
            }
        }
    }       
    translate([0,0,base_thickness]){
        translate([base_dim/2,socket_depth/2,0]){
            relay_socket_and_bnc();
        }        
        translate([base_dim,0,0]){
            translate([socket_depth * -0.5,base_dim/2,0]){
                rotate([0,0,90]){
                    relay_socket_and_bnc();
                }
            }
        }        
        translate([base_dim/2,base_dim - socket_depth/2,0]){
            rotate([0,0,180]){
                relay_socket_and_bnc();
            }
        }        
        translate([socket_depth/2,base_dim/2,0]){
            rotate([0,0,270]){
                relay_socket_and_bnc();
            }
        }               
    }       
}
}

if (make_bridge) {

translate([-1 * bridge_thickness,17,0]){
    difference(){
        rounded_rectangle(base_dim + bridge_thickness * 2 , bridge_width, bridge_height,3);
        
        union(){
            translate([bridge_thickness,-2,-1.6]){
                cube([base_dim, bridge_width*2, bridge_height-1]);
            }
            translate([bridge_thickness,bridge_top_thickness,0]){
                cube([base_dim * bridge_cut_coeff, bridge_width - 4, bridge_height-bridge_top_thickness]);
            }
            translate([bridge_thickness + base_dim * (1 - bridge_cut_coeff),bridge_top_thickness,0]){
                cube([base_dim * bridge_cut_coeff, bridge_width - 4, bridge_height-bridge_top_thickness]);
            }
            translate([base_dim/2 + bnc_mounting_hole_radius,bridge_width/2,relay_height + base_thickness + bridge_thickness -1]){
                cylinder( h = 100, r = bnc_mounting_hole_radius, center = true);
            }
            translate([bridge_thickness/2,bridge_width/2,0]){
                cylinder( h = 100, r = mounting_hole_dia/2, center = true);                
            }
            
            translate([base_dim + bridge_thickness*1.5,bridge_width/2,0]){
                cylinder( h = 100, r = mounting_hole_dia/2, center = true);                
            }
        }
    }

}
}